--- tcs-1.orig/Makefile
+++ tcs-1/Makefile
@@ -29,6 +29,8 @@
 
 #example tcs output files
 
+ex00.utf:	tcs ex00.src
+	./tcs -sf jis ex00.src > $@
 ex01.utf:	tcs ex01.src
 	./tcs -sf jis ex01.src > $@
 ex02.utf:	tcs ex02.src
--- tcs-1.orig/conv_jis.c
+++ tcs-1/conv_jis.c
@@ -76,15 +76,14 @@
 				EPR "%s: unexpected EOF in %s\n", argv0, file);
 			c = 0x21 | (lastc&0x80);
 		}
-		if((lastc&0x80) != (c&0x80)){	/* guard against latin1 in jis */
-			emit(lastc);
-			state = state0;
-			goto again;
-		}
 		if(CANS2J(lastc, c)){	/* ms dos sjis */
 			int hi = lastc, lo = c;
 			S2J(hi, lo);			/* convert to 208 */
 			n = hi*100 + lo - 3232;		/* convert to kuten208 */
+		} else if((lastc&0x80) != (c&0x80)){	/* guard against latin1 in jis */
+			emit(lastc);
+			state = state0;
+			goto again;
 		} else
 			n = (lastc&0x7F)*100 + (c&0x7f) - 3232;	/* kuten208 */
 		if((n >= KUTEN208MAX) || ((l = tabkuten208[n]) == -1)){
@@ -163,15 +162,14 @@
 				EPR "%s: unexpected EOF in %s\n", argv0, file);
 			c = 0x21 | (lastc&0x80);
 		}
-		if((lastc&0x80) != (c&0x80)){	/* guard against latin1 in jis */
-			emit(lastc);
-			state = state0;
-			goto again;
-		}
 		if(CANS2J(lastc, c)){	/* ms dos sjis */
 			int hi = lastc, lo = c;
 			S2J(hi, lo);			/* convert to 208 */
 			n = hi*100 + lo - 3232;		/* convert to kuten208 */
+		} else if((lastc&0x80) != (c&0x80)){	/* guard against latin1 in jis */
+			emit(lastc);
+			state = state0;
+			goto again;
 		} else {
 			nerrors++;
 			if(squawk)
@@ -444,7 +442,7 @@
 		r = base[i];
 		if(r < 128){
 			if(state == jp2022){
-				*p++ = ESC; *p++ = '('; *p++ = 'H';
+				*p++ = ESC; *p++ = '('; *p++ = 'B';
 				state = ascii;
 			}
 			*p++ = r;
--- tcs-1.orig/regress
+++ tcs-1/regress
@@ -3,7 +3,7 @@
 uname -a		# delete this if you don't have one
 make tcs
 echo "no error messages means no errors"
-for i in 01 02 03 04 05 06 07 08 09 10 11 12
+for i in 00 01 02 03 04 05 06 07 08 09 10 11 12
 do
 	f=ex$i
 	rm -f $f.utf
--- tcs-1.orig/debian/rules
+++ tcs-1/debian/rules
@@ -0,0 +1,54 @@
+#!/usr/bin/make -f
+# Derived from dh_make example.
+
+#export DH_VERBOSE=1
+
+CC = gcc
+CFLAGS = -O2 -g -Wall -D_POSIX_SOURCE
+
+build: build-stamp
+build-stamp:
+	dh_testdir
+	$(MAKE) CC="$(CC)" CFLAGS="$(CFLAGS)"
+	touch build-stamp
+
+clean:
+	dh_testdir
+	dh_testroot
+	rm -f build-stamp install-stamp
+	-$(MAKE) clean
+	dh_clean
+
+install: install-stamp
+install-stamp: build-stamp
+	dh_testdir
+	dh_testroot
+	dh_clean -k
+	dh_installdirs usr/bin
+	install -m755 -s tcs debian/tmp/usr/bin
+	touch install-stamp
+
+binary-indep: build install
+# We have nothing to do by default.
+
+binary-arch: build install
+	dh_testdir
+	dh_testroot
+	dh_installdocs tcs.ps
+	dh_installexamples ex*.src
+	dh_installmanpages
+	dh_installchangelogs 
+	dh_strip
+	dh_compress
+	dh_fixperms
+	dh_installdeb
+	dh_shlibdeps
+	dh_gencontrol
+	dh_md5sums
+	dh_builddeb
+
+source diff:                                                                  
+	@echo >&2 'source and diff are obsolete - use dpkg-source -b'; false
+
+binary: binary-indep binary-arch
+.PHONY: build clean binary-indep binary-arch binary
--- tcs-1.orig/debian/changelog
+++ tcs-1/debian/changelog
@@ -0,0 +1,60 @@
+tcs (1-7) unstable; urgency=low
+
+  * Fixed ms-kanji handling (patch by SONE Takeshi <ts1@cma.co.jp>)
+    (closes: #58972)
+
+ -- Frederic Peters <fpeters@debian.org>  Wed,  1 Mar 2000 14:56:05 +0100
+
+tcs (1-6) unstable; urgency=low
+
+  * Moved to FHS
+
+ -- Frederic Peters <fpeters@debian.org>  Thu,  9 Sep 1999 19:50:00 +0200
+
+tcs (1-5) unstable; urgency=low
+
+  * I forgot to change the maintainer field ...
+
+ -- Frederic Peters <fpeters@debian.org>  Mon,  9 Aug 1999 19:30:20 +0200
+ 
+tcs (1-4.2) unstable; urgency=low
+
+  * New maintainer
+  * Fixed bug #28602
+
+ -- Frederic Peters <fpeters@debian.org>  Fri,  6 Aug 1999 11:56:02 +0200
+ 
+tcs (1-4.1) unstable; urgency=low
+
+  * Non maintainer upload.
+  * Converted debian/rules to debhelper; changed debian/control a bit.
+
+ -- Josip Rodin <jrodin@jagor.srce.hr>  Tue, 15 Jun 1999 23:04:25 +0200
+
+tcs (1-4) unstable; urgency=low
+
+  * Interim maintainer release
+  * Set maintainer field to debian-qa, i.e. orphaning it.
+  * Updated Standards-Version
+
+ -- Martin Schulze <joey@finlandia.infodrom.north.de>  Sat, 24 Oct 1998 15:19:23 +0200
+
+tcs (1-3) unstable; urgency=low
+
+  * Recompiled with libc6.
+
+ -- Karl Sackett <krs@debian.org>  Wed, 25 Jun 1997 10:14:09 -0500
+
+tcs (1-2) unstable; urgency=low
+
+  * Converted to new package standards.
+  * Maintainer address changed.
+
+ -- Karl Sackett <krs@debian.org>  Wed, 23 Oct 1996 16:16:22 -0500
+
+1-1
+        * Added Debian support files.
+
+Local variables:
+mode: debian-changelog
+End:
--- tcs-1.orig/debian/control
+++ tcs-1/debian/control
@@ -0,0 +1,15 @@
+Source: tcs
+Section: text
+Priority: optional
+Maintainer: Frederic Peters <fpeters@debian.org>
+Standards-Version: 3.0.1.1
+
+Package: tcs
+Architecture: any
+Depends: ${shlibs:Depends}
+Description: Character set translator.
+ tcs translates character sets from one encoding to another.
+ .
+ Supported encodings include utf (ISO utf-8), ascii, ISO 8859-[123456789], 
+ koi8, jis-kanji, ujis, ms-kanji, jis, gb, big5, unicode, tis, msdos, and
+ atari.
--- tcs-1.orig/debian/copyright
+++ tcs-1/debian/copyright
@@ -0,0 +1,25 @@
+This is the Debian GNU/Linux prepackaged version of tcs.
+
+This package is now maintained by Frederic Peters <fpeters@debian.org>,
+it was put together by Karl Sackett <krs@debian.org>, from sources
+obtained from:
+        ftp://plan9.att.com/plan9/unixsrc/tcs.shar.Z
+
+For more information see:
+        http://www.gh.cs.usyd.edu.au/~matty/9term/
+
+License:
+
+tcs:
+ * The authors of this software are Rob Pike and Howard Trickey.
+ *              Copyright (c) 1992 by AT&T.
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose without fee is hereby granted, provided that this entire notice
+ * is included in all copies of any software which is or includes a copy
+ * or modification of this software and in all copies of the supporting
+ * documentation for such software.
+ * THIS SOFTWARE IS BEING PROVIDED "AS IS", WITHOUT ANY EXPRESS OR IMPLIED
+ * WARRANTY.  IN PARTICULAR, NEITHER THE AUTHORS NOR AT&T MAKE ANY
+ * REPRESENTATION OR WARRANTY OF ANY KIND CONCERNING THE MERCHANTABILITY
+ * OF THIS SOFTWARE OR ITS FITNESS FOR ANY PARTICULAR PURPOSE.
+        - Rob Pike, AT&T Bell Laboratories
--- tcs-1.orig/ex00.ok
+++ tcs-1/ex00.ok
@@ -0,0 +1,192 @@
+From dmr Thu Jan 30 17:00:03 EST 1992
+誠に申し訳ありませんが、MH front end はあと１週間だけ待って下さい。
+新しい xterm のために vtwin の変更が必要となって、それにちょっと
+手間取ってしまいました。まだもう１つ直したい bug があるのですが
+もう今日は時間がありません。
+拝啓　新緑の候、ますますご清祥のこととお喜び申し上げます。
+さて、斎藤信男先生は４月１日をもちまして、慶応義塾大学理工学部教
+授に御昇任なられました。そこで、日頃斎藤先生にお世話になっている
+私達が斎藤先生に お祝いを申し上げるためのささやかな 祝宴を企画致
+しました。当日は  斎藤研究室 OB/OG の方々、斎藤研究室現役の学生、
+また、斎藤先生ゆかりの方々が集まり、斎藤先生を囲んで楽しいひとと
+きを過ごしたいと考えております。ご家族、御友人おさそいあわせのう
+え御列席下さるようお願い申し上げます。
+おそれいりますが、ご出席の確認を下記連絡先に電話または電子メール
+にてご連絡下さるようお願い申し上げます。
+                            				敬具
+                    「斎藤信男教授を囲む会」
+日時： 昭和６２年４月２４日（金） 18:00 より
+場所： 新橋第一ホテル「レストランクラレット」
+       電話；　 03-501-4411
+会費： １万５千円 （当日記念品代１口５千円を別に御用意下さい。）
+	ただし、学生料金は別途設定してありますので御安心！
+連絡先:中村　修  osamu@keio.junet
+       電話 044-63-9137 （斎藤研究室直通）
+       電話 03-704-4715 （中村自宅）
+		         幹事代表	村井　純、　中村 修
+拝啓　新緑の候、ますますご清祥のこととお喜び申し上げます。
+さて、斎藤信男先生は４月１日をもちまして、慶応義塾大学理工学部教
+授に御昇任なられました。そこで、日頃斎藤先生にお世話になっている
+私達が斎藤先生に お祝いを申し上げるためのささやかな 祝宴を企画致
+しました。当日は  斎藤研究室 OB/OG の方々、斎藤研究室現役の学生、
+また、斎藤先生ゆかりの方々が集まり、斎藤先生を囲んで楽しいひとと
+きを過ごしたいと考えております。ご家族、御友人おさそいあわせのう
+え御列席下さるようお願い申し上げます。
+おそれいりますが、ご出席の確認を下記連絡先に電話または電子メール
+にてご連絡下さるようお願い申し上げます。
+                            				敬具
+                    「斎藤信男教授を囲む会」
+日時： 昭和６２年４月２４日（金） 18:00 より
+場所： 新橋第一ホテル「レストランクラレット」
+       電話；　 03-501-4411
+会費： １万５千円 （当日記念品代１口５千円を別に御用意下さい。）
+	ただし、学生料金は別途設定してありますので御安心！
+連絡先:中村　修  osamu@keio.junet
+       電話 044-63-9137 （斎藤研究室直通）
+       電話 03-704-4715 （中村自宅）
+		         幹事代表	村井　純、　中村 修
+ＪＵＳ幹事の皆様：
+４月１０日の幹事会でお話した、次のような講演についての件ですが、
+	発内容：Ｍａｃｉｎｔｏｓｈ　ＩＩへのＵＮＩＸの移植
+	発  者：米国ＵｎｉＳｏｆｔのエンジニア
+	発時間：１時間（幹事会において決まった時間です）
+	発当人からＡＢＳＴＲＡＣＴが届きました。このような内容での話でよけれ
+ば、来日するがどうだろう？との問い合わせがあったのですが、皆様いかがでしょうか？
+皆様の御意見を伺ったうえで、本当に来てもらうかどうか当人に連絡したいと思います。
+（交通費、宿泊費などはＪＵＳから出す必要はありません）
+御返答、よろしくお願いいたします。
+						ＤＣＬ　坂本　文
+ＪＵＳ幹事の皆様：
+４月１０日の幹事会でお話した、次のような講演についての件ですが、
+	発内容：Ｍａｃｉｎｔｏｓｈ　ＩＩへのＵＮＩＸの移植
+	発  者：米国ＵｎｉＳｏｆｔのエンジニア
+	発時間：１時間（幹事会において決まった時間です）
+	発当人からＡＢＳＴＲＡＣＴが届きました。このような内容での話でよけれ
+ば、来日するがどうだろう？との問い合わせがあったのですが、皆様いかがでしょうか？
+皆様の御意見を伺ったうえで、本当に来てもらうかどうか当人に連絡したいと思います。
+（交通費、宿泊費などはＪＵＳから出す必要はありません）
+御返答、よろしくお願いいたします。
+						ＤＣＬ　坂本　文
+	次回のｊｕｓ幹事会は下記の場所で行います。
+日時	５／８（金）午後６時
+場所	（株）アスキ?、ＦＦＦビル、７Ｆ役員会議室
+地図
+	至赤坂
+国道２４６号（青山通り）
+	| |*（地下鉄表参道Ｂ３出口）
+	| |					（ラ?メン屋）
+紀ノ国屋| |出光GS				天下一
+	| |		住	      大	Ｆ*
+	| |		友	      仁	Ｆ
+	| |		南	      堂	Ｆ
+	至渋谷		青	      ビ	ビ
+			山	      ル	ル
+			ビ
+			ル
+（１）地下鉄表参道駅下車、Ｂ３の出口を出る。
+（２）青山通りを渋谷方面へ歩く
+（３）初めての信号（角が出光ＧＳ）を右へ曲る
+（４）約５００Ｍ歩き（信号４つ目）、Ｔ字路の交差点の右側
+（５）ＦＦＦビルの７Ｆ
+ＰＳ．当日１４：４０着の便で成田に帰って来ますので、少し遅れるかもしれません
+      が先に始めて下さい。
+	この間の集りでマーク・シートの読み取りのsoftの話題があったと思うので
+すが，「インタフェース５月号」の新製品紹介の欄で，ANK character の読み取りの
+softの紹介があったように思います。
+	ただ，その雑誌がいま，手元にないので詳しくはわかりませんが，調べてみ
+ます。
+一部の人は知っていると思いますが，現在 rmap のＰＤ化を進めています．
+余分な機能をそぎ落し，一通り動くようになりました．あと，２，３
+新たな機能を追加する予定ですが，問題はその前提となる rwhod にあります．
+御存知のように rwhod はつながるマシンの数が増えると，急激に network 及び
+CPU を食いはじめます．また，routing の機能がないため複数のネットワークが
+接続されているような環境ではやはり問題です．東工大ではいままで，gateway
+となるマシンの rwhod に手をいれて routing をするようにしていましたが，
+その場しのぎのいい加減なやり方だったので，４月にネットワークの接続形態が
+変って以来，２重に packet を流していたことが判明しました．昨日急いで
+直しましたが，それまでネットワークは collision の嵐だった訳です．
+たかだか３０台のネットワークでこの有様ですから，何百，何千という
+本格的ネットワークを考えると単純に routing を行う今の方法は非現実的です．
+そこで，いくつかのアイディアを加藤君と考えました．
+1.  broadcast packet は止めて，ＮＦＳを利用し /usr/spool/rwho をできる限り
+　共有する．どうしても必要なところは point-to-point で routing を行う．
+2.  routing する場合に独自のプロトコルにより複数のホストの情報を
+  1 packet で送る．
+3.  on demand で必要な時だけ他のマシンに対し情報を要求する．
+  トリガーは，例えば誰かが rmap でそのマシンを含むページを表示しようと
+　した時とする．
+4.  どうせ，そういう情報が必要なのは phone をかけたい時ぐらいだから，
+　むしろ，phone を改造して phoned が broadcasting や routing をしながら，
+　特定のユーザがどこにいるか探し回るようにする．
+さて，そこで皆さんの意見を聞きたいと思います．どうするのが一番良いでしょうか．
+今考えているのは，1, 2 の機能を持った public domain rwhod を作るといった
+ところですが，果してそんなことをするのは意味があるのか．４を実現すれば事実上
+rmap はいらなくなるんじゃないのか．有益な議論をお待ちしています．
+私は前の mail で次ぎのようなことを書きました．
+> 御存知のように rwhod はつながるマシンの数が増えると，急激に network 及び
+> CPU を食いはじめます．また，routing の機能がないため複数のネットワークが
+> 接続されているような環境ではやはり問題です．東工大ではいままで，gateway
+> となるマシンの rwhod に手をいれて routing をするようにしていましたが，
+> ....，何百，何千という
+> 本格的ネットワークを考えると単純に routing を行う今の方法は非現実的です．
+> そこで，いくつかのアイディアを加藤君と考えました．
+> 1.  broadcast packet は止めて，ＮＦＳを利用し /usr/spool/rwho をできる限り
+> 　共有する．どうしても必要なところは point-to-point で routing を行う．
+> 2.  routing する場合に独自のプロトコルにより複数のホストの情報を
+>   1 packet で送る．
+> 今考えているのは，1, 2 の機能を持った public domain rwhod を作るといった
+> ところですが，果してそんなことをするのは意味があるのか．...
+今考えていることを，もう少し具体的に説明すると，
+既存の rwhod は自分のマシンの network configuration を見て
+自分の属するサブネットワークにはすべて broadcasting で，
+point-to-point のリンクにはその相手先に対し，自分のマシンの情報のみを
+流しまています．
+私が手を入れた rwhod はそれらに加えて，他のマシンから来た
+情報を自分の spool に書き込むと同時に，リストとして貯め込んでおき，
+自分の情報を流す時に同時に，個々のマシンの属するネットワーク以外の
+すべてのリンクにその情報をリレーするというものです．
+しかし，この方法だといくら broadcast packet を使ったところで，
+論理的にはネットワーク全体が完全グラフをなすように packet を
+流すことになりますし，しかも普段はそういう情報を必要としない
+場合が多い訳ですから，明らかに供給過剰です．で，これを少しでも
+軽減することができれば，と考えている訳です．
+新しい rwhod は，様々なネットワーク上の制約を盛り込めるように，
+例えば /etc/rwhod.rc のようなファイルからリレーのための configuration
+を読み込むようにするといいでしょう．そのファイルの中に書かれるべき
+項目としては，次ぎのようなものが考えられます．
+1.  自分のマシンの情報をどのマシン，またはどのネットワークに対して
+　　送信するか．また，それをローカルファイルに格納するか否か．
+2.  他のマシンの情報をどのマシン，またはどのネットワークに対して
+　　リレーするか．それは packet として受信されるべきものなのか，
+　　ＮＦＳによってそのマシンの rwhod が書き込んだファイルを
+　　読みにいくのか．前者の場合には，さらにその情報をローカル
+　　ファイルに格納するか否か．
+3.  1, 2 は何秒間隔で行うのか．
+これらに加え，さらに通常は packet を流さずに必要な時だけ，
+rwhod が他のマシンに対し情報を要求するという機能を付け加えるのも
+いいかもしれません．このためには，/etc/rwhod.rc の中に
+4.  あるマシンの情報に対する要求があった時にどのマシンに
+　　対して問い合わせを行うか．
+という項目を付け加えるべきでしょう．1,2,4 は実際には統一した
+フォーマットで記述するのがいいかもしれません．
+もし，こういう on demand 型のサービスを取り入れると当然 rwho, ruptime, rmap
+といった client 側にも変更が必要になります．恐らくあるマシンの情報を得るには，
+といったようなライブラリ関数を用意することになるでしょう．
+この関数は自分のマシンの rwhod に対してそういう request を
+行い response を受け取るという単純なものにするのがいいと
+思います．一方その request を受け取った rwhod はスプールを
+見てそれが充分新しいものであれば，そこから読み取り，そうでなければ
+rwhod.rc に書かれたマシンに対し問い合わせることになるでしょう．
+いや，もうそこまでするのだったら，いっそスプールは全廃して
+rwhod が on core で情報を管理した方がいいかもしれません．
+というようなところが今まで考えたところですが，そこでこの前にも書いた
+疑問に戻ります．果してこんなことをする意味があるのだろうか？
+phone を hack すれば，それで問題は解決するのではないか？
+何か意見を言ってください．お願いします．
+私はこれを今度の meeting で議論してもらいたいとは思っていません．
+あくまで mail で意見を聞かせて下さい．そうすることで，
+議論がたまたま meeting に出席した人の中だけでの閉じたもので
+終るということがなくなると思いますから．
+ところでこの mailing list はいつまで東工大で管理されているのですか．
+u-tokyo に移した方がいいのではないのですか？
+
--- tcs-1.orig/ex00.src
+++ tcs-1/ex00.src
@@ -0,0 +1,192 @@
+From dmr Thu Jan 30 17:00:03 EST 1992
+ɐ\󂠂܂񂪁AMH front end ͂ƂPTԂ҂ĉB
+V xterm ̂߂ vtwin ̕ύXKvƂȂāAɂ
+ԎĂ܂܂B܂P bug ̂ł
+͎Ԃ܂B
+q[@V΂̌A܂܂˂̂ƂƂѐ\グ܂B
+āA֓Mj搶͂SP܂āAc`mwHw
+Ɍ䏸CȂ܂BŁA֓搶ɂbɂȂĂ
+B֓搶 j\グ邽߂̂₩ jv
+܂B  ֓ OB/OG ̕XA֓̊wA
+܂A֓搶䂩̕XW܂A֓搶͂ŊyЂƂ
+߂ƍlĂ܂BƑAFl킹̂
+ȉ悤肢\グ܂B
+ꂢ܂AoȂ̊mFLAɓdb܂͓dq[
+ɂĂA悤肢\グ܂B
+                            				h
+                    u֓Mj͂މv
+F aUQNSQSij 18:00 
+ꏊF VzeuXgNbgv
+       dbG@ 03-501-4411
+F PT~ iLOiPT~ʂɌpӉBj
+	Aw͕ʓrݒ肵Ă܂̂ŌSI
+A:@C  osamu@keio.junet
+       db 044-63-9137 i֓ʁj
+       db 03-704-4715 ij
+		         \	@A@ C
+q[@V΂̌A܂܂˂̂ƂƂѐ\グ܂B
+āA֓Mj搶͂SP܂āAc`mwHw
+Ɍ䏸CȂ܂BŁA֓搶ɂbɂȂĂ
+B֓搶 j\グ邽߂̂₩ jv
+܂B  ֓ OB/OG ̕XA֓̊wA
+܂A֓搶䂩̕XW܂A֓搶͂ŊyЂƂ
+߂ƍlĂ܂BƑAFl킹̂
+ȉ悤肢\グ܂B
+ꂢ܂AoȂ̊mFLAɓdb܂͓dq[
+ɂĂA悤肢\グ܂B
+                            				h
+                    u֓Mj͂މv
+F aUQNSQSij 18:00 
+ꏊF VzeuXgNbgv
+       dbG@ 03-501-4411
+F PT~ iLOiPT~ʂɌpӉBj
+	Aw͕ʓrݒ肵Ă܂̂ŌSI
+A:@C  osamu@keio.junet
+       db 044-63-9137 i֓ʁj
+       db 03-704-4715 ij
+		         \	@A@ C
+itr̊FlF
+SPO̊łbÂ悤ȍuɂĂ̌łA
+	eFl@hhւ̂tmhẅڐA
+	  ҁFčtr̃GWjA
+	ԁFPԁiɂČ܂Ԃłj
+	l`arsq`bs͂܂B̂悤ȓeł̘bł悯
+΁A邪ǂ낤HƂ̖₢킹̂łAFlł傤H
+FľӌfŁA{ɗĂ炤ǂlɘAƎv܂B
+iʔAhȂǂ͂itroKv͂܂j
+ԓA낵肢܂B
+						cbk@{@
+itr̊FlF
+SPO̊łbÂ悤ȍuɂĂ̌łA
+	eFl@hhւ̂tmhẅڐA
+	  ҁFčtr̃GWjA
+	ԁFPԁiɂČ܂Ԃłj
+	l`arsq`bs͂܂B̂悤ȓeł̘bł悯
+΁A邪ǂ낤HƂ̖₢킹̂łAFlł傤H
+FľӌfŁA{ɗĂ炤ǂlɘAƎv܂B
+iʔAhȂǂ͂itroKv͂܂j
+ԓA낵肢܂B
+						cbk@{@
+	͉̂L̏ꏊōs܂B
+	T^WijߌU
+ꏊ	ijAXL?AeeerAVec
+n}
+	ԍ
+QSUiRʂj
+	| |*inS\QaRoj
+	| |					i?j
+Im| |oGS				V
+	| |		Z	      	e*
+	| |		F	      m	e
+	| |			      	e
+	aJ			      r	r
+			R	      	
+			r
+			
+iPjnS\QwԁAaȐooB
+iQjRʂaJʂ֕
+iRj߂Ă̐MipofrjE֋Ȃ
+iSjTOOliMSځjAsȞ_̉E
+iTjeeer̂Ve
+orDPSFSO̕ւŐcɋAė܂̂ŁAx邩܂
+      Ɏn߂ĉB
+	̊Ԃ̏WŃ}[NEV[g̓ǂݎsoft̘b肪Ǝv̂
+CuC^tF[XTv̐ViЉ̗ŁCANK character ̓ǂݎ
+soft̏Љ悤Ɏv܂B
+	C̎G܁C茳ɂȂ̂ŏڂ͂킩܂񂪁CׂĂ
+܂B
+ꕔ̐l͒mĂƎv܂C rmap ̂oci߂Ă܂D
+]ȋ@\Cʂ蓮悤ɂȂ܂DƁCQCR
+Vȋ@\ǉ\łC͂̑OƂȂ rwhod ɂ܂D
+䑶m̂悤 rwhod ͂Ȃ}V̐ƁC} network y
+CPU H͂߂܂D܂Crouting ̋@\Ȃߕ̃lbg[N
+ڑĂ悤Ȋł͂͂łDHł͂܂܂ŁCgateway
+ƂȂ}V rwhod Ɏ routing 悤ɂĂ܂C
+̏ꂵ̂̂Ȃ̂ŁCSɃlbg[N̐ڑ`Ԃ
+ςĈȗCQd packet 𗬂ĂƂ܂D}
+܂C܂Ńlbg[N collision ̗łD
+RÕlbg[Nł̗LlłCSCƂ
+{iIlbg[NlƒP routing s̕@͔񌻎IłD
+ŁC̃ACfBANƍl܂D
+1.  broadcast packet ͎~߂āCmer𗘗p /usr/spool/rwho ł
+@LDǂĂKvȂƂ point-to-point  routing sD
+2.  routing ꍇɓƎ̃vgRɂ蕡̃zXg̏
+  1 packet őD
+3.  on demand ŕKvȎ̃}Vɑ΂vD
+  gK[́CႦΒN rmap ł̃}V܂ރy[W\悤
+@ƂD
+4.  ǂC񂪕KvȂ̂ phone 炢C
+@ނCphone  phoned  broadcasting  routing ȂC
+@̃[Uǂɂ邩T悤ɂD
+āCŊF̈ӌ𕷂Ǝv܂Dǂ̂ԗǂł傤D
+lĂ̂́C1, 2 ̋@\ public domain rwhod Ƃ
+ƂłCʂĂȂƂ͈̂Ӗ̂DSΎ
+rmap ͂ȂȂ񂶂Ȃ̂DLvȋc_҂Ă܂D
+͑O mail Ŏ̂悤ȂƂ܂D
+> 䑶m̂悤 rwhod ͂Ȃ}V̐ƁC} network y
+> CPU H͂߂܂D܂Crouting ̋@\Ȃߕ̃lbg[N
+> ڑĂ悤Ȋł͂͂łDHł͂܂܂ŁCgateway
+> ƂȂ}V rwhod Ɏ routing 悤ɂĂ܂C
+> ....CSCƂ
+> {iIlbg[NlƒP routing s̕@͔񌻎IłD
+> ŁC̃ACfBANƍl܂D
+> 1.  broadcast packet ͎~߂āCmer𗘗p /usr/spool/rwho ł
+> @LDǂĂKvȂƂ point-to-point  routing sD
+> 2.  routing ꍇɓƎ̃vgRɂ蕡̃zXg̏
+>   1 packet őD
+> lĂ̂́C1, 2 ̋@\ public domain rwhod Ƃ
+> ƂłCʂĂȂƂ͈̂Ӗ̂D...
+lĂ邱ƂC̓IɐƁC
+ rwhod ͎̃}V network configuration 
+̑Tulbg[Nɂׂ͂ broadcasting ŁC
+point-to-point ̃Nɂ͂̑ɑ΂C̃}V݂̏̂
+܂Ă܂D
+ꂽ rwhod ͂ɉāC̃}V痈
+ spool ɏނƓɁCXgƂĒߍłC
+̏𗬂ɓɁCX̃}V̑lbg[NȊO
+ׂẴNɂ̏[Ƃ̂łD
+C̕@Ƃ broadcast packet gƂŁC
+_Iɂ̓lbg[NŜSOtȂ悤 packet 
+ƂɂȂ܂Ci͂KvƂȂ
+ꍇłC炩ɋߏłDŁCł
+y邱Ƃł΁CƍlĂłD
+V rwhod ́ClXȃlbg[N̐𐷂荞߂悤ɁC
+Ⴆ /etc/rwhod.rc ̂悤ȃt@C烊[̂߂ configuration
+ǂݍނ悤ɂƂł傤D̃t@C̒ɏׂ
+ڂƂẮĈ悤Ȃ̂l܂D
+1.  ̃}V̏ǂ̃}VC܂͂ǂ̃lbg[Nɑ΂
+@@M邩D܂C[Jt@CɊi[邩ۂD
+2.  ̃}V̏ǂ̃}VC܂͂ǂ̃lbg[Nɑ΂
+@@[邩D packet ƂĎMׂ̂Ȃ̂C
+@@merɂẴ}V rwhod 񂾃t@C
+@@ǂ݂ɂ̂DO҂̏ꍇɂ́Cɂ̏[J
+@@t@CɊi[邩ۂD
+3.  1, 2 ͉bԊuōŝD
+ɉCɒʏ packet 𗬂ɕKvȎC
+rwhod ̃}Vɑ΂vƂ@\t̂
+܂D̂߂ɂ́C/etc/rwhod.rc ̒
+4.  }V̏ɑ΂vɂǂ̃}V
+@@΂Ė₢킹sD
+Ƃڂtׂł傤D1,2,4 ͎ۂɂ͓ꂵ
+tH[}bgŋLq̂܂D
+C on demand ^̃T[rXƓR rwho, ruptime, rmap
+Ƃ client ɂύXKvɂȂ܂D炭}V̏𓾂ɂ́C
+Ƃ悤ȃCu֐pӂ邱ƂɂȂł傤D
+̊֐͎̃}V rwhod ɑ΂Ă request 
+s response 󂯎ƂPȂ̂ɂ̂
+v܂D request 󂯎 rwhod ̓Xv[
+Ăꂪ[V̂ł΁CǂݎCłȂ
+rwhod.rc ɏꂽ}Vɑ΂₢킹邱ƂɂȂł傤D
+C܂ł̂CXv[͑Sp
+rwhod  on core ŏǗ܂D
+Ƃ悤ȂƂ낪܂ōlƂłCł̑Oɂ
+^ɖ߂܂DʂĂȂƂӖ̂낤H
+phone  hack ΁CŖ͉̂ł͂ȂH
+ӌĂD肢܂D
+͂x meeting ŋc_Ă炢Ƃ͎vĂ܂D
+܂ mail ňӌ𕷂ĉD邱ƂŁC
+c_܂ meeting ɏoȂl̒ł̕̂
+IƂƂȂȂƎv܂D
+Ƃł mailing list ͂܂œHŊǗĂ̂łD
+u-tokyo Ɉڂ̂ł͂Ȃ̂łH
+
